@@ -4,7 +4,7 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.09';
 
 require 'Mango.pm'; # Bit useless if you don't actually have mango
 use Test::Mock::Mango::FakeData;
@@ -15,6 +15,16 @@ $Test::Mock::Mango::data  = Test::Mock::Mango::FakeData->new;
 $Test::Mock::Mango::error = undef;
 $Test::Mock::Mango::n     = undef;
 
+
+# Stub "Mango" itself to deal with the situations where it'll get
+# a duff or unset connection string (if for example the context in
+# which the code will run requires a config file but the unit test
+# will run where this file doesn't exist).
+{
+    no warnings 'redefine';
+    *Mango::new = sub { bless {}, 'Mango' };
+}
+
 # If we're running with Test::Spec and in appropriate context
 # then use Test::Spec::Mocks to do our monkey patching.
 if (exists $INC{'Test/Spec.pm'} && Test::Spec->current_context) {
@@ -23,7 +33,7 @@ if (exists $INC{'Test/Spec.pm'} && Test::Spec->current_context) {
 }
 else {
     no warnings 'redefine';
-    eval( q|*Mango::db = sub{Test::Mock::Mango::DB->new($_[-1])}| );
+    *Mango::db = sub{Test::Mock::Mango::DB->new($_[-1])};
 }
 
 
@@ -62,6 +72,8 @@ Test::Mock::Mango - Simple stubbing for Mango to allow unit tests for code that
 
 =head1 DESCRIPTION
 
+For L<Mango> version 0.30 and higher
+
 L<Test::Mock::Mango> provides simple stubbing of methods in the L<Mango> library
 to allow easier unit testing of L<Mango> based code.
 
@@ -152,7 +164,7 @@ Doesn't remove anything.
 
 L<Test::Mock::Mango::Cursor>
 
-=over 4
+=over 6
 
 =item all
 
@@ -172,6 +184,14 @@ Returns the number of documents in the current fake collection.
 
 Arbitarily returns 'C<2>'
 
+=item limit
+
+Passthru
+
+=item sort
+
+Passthru
+
 =back
 
 
