@@ -28,6 +28,12 @@ sub all {
 
 # ------------------------------------------------------------------------------
 
+# Naive no-op. Just return the parent so it can chain.
+sub limit { shift }
+sub sort { shift }
+
+# ------------------------------------------------------------------------------
+
 # Naive "next" - simply iterate through the docs in the defined test data
 sub next {
 	my ($self, $cb) = @_;
